# nearust

`nearust` is a tool for fast detection of nearest neighbour strings that fall
within a threshold edit distance. It is a fast, multi-threaded, CPU-based
implementation of Chotisorayuth and Mayer's [symdel
algorithm](https://arxiv.org/abs/2403.09010v1).

### Check out the [documentation page](https://nearust.readthedocs.io).
